@@ -31,6 +31,9 @@
 #
 
 package HTML::Mason::Request;
+{
+  $HTML::Mason::Request::VERSION = '1.52';
+}
 
 use strict;
 use warnings;
@@ -311,7 +314,7 @@ sub _initialize {
                     #
                     {
                         no strict 'refs';
-                        unless (defined(%{$plugin . "::"})) {
+                        unless (keys %{$plugin . "::"}) {
                             eval "use $plugin;";
                             die $@ if $@;
                         }
@@ -343,7 +346,7 @@ sub _initialize {
 sub use_dhandlers
 {
     my $self = shift;
-    return defined $self->{dhandler_name} and length $self->{dhandler_name};
+    return (defined $self->{dhandler_name} and length $self->{dhandler_name});
 }
 
 sub alter_superclass
@@ -1452,15 +1455,6 @@ sub request_args
 *top_args = \&request_args;
 *top_comp = \&request_comp;
 
-# deprecated in 1.1x
-sub time
-{
-    my ($self) = @_;
-    my $time = $self->interp->current_time;
-    $time = time() if $time eq 'real';
-    return $time;
-}
-
 #
 # Subroutine called by every component while in debug mode, convenient
 # for breakpointing.
@@ -1557,6 +1551,9 @@ sub log
 }
 
 package Tie::Handle::Mason;
+{
+  $Tie::Handle::Mason::VERSION = '1.52';
+}
 
 sub TIEHANDLE
 {
@@ -1590,10 +1587,16 @@ sub PRINTF
 
 __END__
 
+=pod
+
 =head1 NAME
 
 HTML::Mason::Request - Mason Request Class
 
+=head1 VERSION
+
+version 1.52
+
 =head1 SYNOPSIS
 
     $m->abort (...)
@@ -1689,7 +1692,7 @@ To use the CHI C<FastMmap> driver by default:
     data_cache_api      => 'CHI',
     data_cache_defaults => {driver => 'FastMmap'},
 
-These settings are overriden by options given to particular
+These settings are overridden by options given to particular
 C<$m-E<gt>cache> calls.
 
 =item dhandler_name
@@ -1903,7 +1906,7 @@ defaults to C<FileCache> in most cases, or C<MemoryCache> if the
 interpreter has no data directory, and must be a backend subclass of
 C<Cache::Cache>. The prefix "Cache::" need not be included.  See the
 C<Cache::Cache> package for a full list of backend subclasses.
- 
+
 Beyond that, I<cache_options> may include any valid options to the new() method of the
 cache class. e.g. for C<FileCache>, valid options include C<default_expires_in> and
 C<cache_depth>.
@@ -2541,14 +2544,33 @@ exceptions, like this:
 
 =back
 
-=head1 AUTHORS
-
-Jonathan Swartz <swartz@pobox.com>, Dave Rolsky <autarch@urth.org>, Ken Williams <ken@mathforum.org>
-
 =head1 SEE ALSO
 
-L<HTML::Mason|HTML::Mason>,
-L<HTML::Mason::Devel|HTML::Mason::Devel>,
-L<HTML::Mason::Component|HTML::Mason::Component>
+L<Mason|Mason>
+
+=head1 AUTHORS
+
+=over 4
+
+=item *
+
+Jonathan Swartz <swartz@pobox.com>
+
+=item *
+
+Dave Rolsky <autarch@urth.org>
+
+=item *
+
+Ken Williams <ken@mathforum.org>
+
+=back
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2012 by Jonathan Swartz.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
